/*
 * $Id: HostCache.java 238 2005-08-15 22:26:43Z davidb $
 *
 * Copyright (c) 2005 VeriSign, Inc. All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 *
 * 1. Redistributions of source code must retain the above copyright
 *    notice, this list of conditions and the following disclaimer.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice, this list of conditions and the following disclaimer in the
 *    documentation and/or other materials provided with the distribution.
 * 3. The name of the author may not be used to endorse or promote products
 *    derived from this software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE AUTHOR ``AS IS'' AND ANY EXPRESS OR
 * IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED WARRANTIES
 * OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE DISCLAIMED.
 * IN NO EVENT SHALL THE AUTHOR BE LIABLE FOR ANY DIRECT, INDIRECT,
 * INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES (INCLUDING, BUT
 * NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES; LOSS OF USE,
 * DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY
 * THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF
 * THIS SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 */

package se.rfc.unbound.cache;

import java.net.InetAddress;
import java.util.Properties;

import org.xbill.DNS.Name;

import se.rfc.unbound.Host;

/**
 * This is the main interface for the "host" cache: this cache stores
 * information about individual nameservers by IP address.
 * 
 * @author davidb
 * @version $Revision: 238 $
 */
public interface HostCache
{

  /**
   * Initialize the host cache.
   * 
   * @param config The configuration data.
   */
  public void init(Properties config);

  /**
   * Lookup a given Host via its IP address (the real key).
   * 
   * @param address the IP address.
   * @return a Host object from the cache. This will be a newly created host
   *         object if the key wasn't present in the cache.
   */
  public Host lookup(InetAddress address);

  /**
   * Mark a given address as "lame" for a given zone -- that is, this
   * nameserver, while listed as authorative for the zone from the parent, was
   * not authoritative for the zone.
   */
  public void markLame(Host host, Name zone, int dclass);
  
  /**
   * @param address The IP address of the nameserver target.
   * @param zone The name of the delegated zone.
   * @return true if the given nameserver is marked as lame for the given zone.
   */
  public boolean isLame(Host host, Name zone, int dclass);
}